==> gerris_0.2.0.orig.tar.gz: tutorial/images.pl <==
# LaTeX2HTML 2002-2 (1.70)
# Associate images original text with physical files.


$key = q/includegraphics[angle=90,width=0.8hsize]{boundaries.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="457" HEIGHT="127" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="\includegraphics[angle=90,width=0.8\hsize]{boundaries.eps}">|; 

$key = q/displaystyle{|nablatimes{{bf{v}|Deltaxovermax|{{bf{v}|};MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="82" HEIGHT="54" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="$\displaystyle {\vert\nabla\times{\bf v}\vert\Delta x\over\max\vert{\bf v}\vert}$">|; 

$key = q/rightarrow;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$ \rightarrow$">|; 

$key = q/displaystyledelta;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="$\displaystyle \delta$">|; 

$key = q/includegraphics[angle=90,width=0.6hsize]{refined1_cells.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="338" HEIGHT="286" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="\includegraphics[angle=90,width=0.6\hsize]{refined1_cells.eps}">|; 

$key = q/displaystylepi;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="29" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="$\displaystyle \pi$">|; 

$key = q/includegraphics[angle=90,width=0.6hsize]{gfs2oogl.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="332" HEIGHT="284" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="\includegraphics[angle=90,width=0.6\hsize]{gfs2oogl.eps}">|; 

$key = q/includegraphics[angle=90,width=0.6hsize]{refined1.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="338" HEIGHT="286" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="\includegraphics[angle=90,width=0.6\hsize]{refined1.eps}">|; 

$key = q/includegraphics[width=0.3hsize]{half-cylinder.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="166" HEIGHT="167" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="\includegraphics[width=0.3\hsize]{half-cylinder.eps}">|; 

$key = q/{figure}center{htmlimage{scale=2.0,external,thumbnail=1}includegraphics[width=hsize]{dxscreen.eps}center{{{{figure};FSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<A NAME="figure403"
 HREF="img7.png"><IMG
 WIDTH="368" HEIGHT="329"
 SRC="|."$dir".q|Timg7.png"
 ALT="\begin{figure}\begin{center}
\includegraphics[width=\hsize]{dxscreen.eps}
\end{center}
\end{figure}"></A>|; 

$key = q/includegraphics[width=0.4hsize]{vorticity.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="221" HEIGHT="222" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="\includegraphics[width=0.4\hsize]{vorticity.eps}">|; 

$key = q/Delta;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="17" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$ \Delta$">|; 

$key = q/bf{v;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="13" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="$ \bf v$">|; 

$key = q/delta;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="$ \delta$">|; 

$key = q/includegraphics[angle=90,width=0.8hsize]{refined2.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="464" HEIGHT="121" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="\includegraphics[angle=90,width=0.8\hsize]{refined2.eps}">|; 

$key = q/includegraphics[width=0.4hsize]{direction.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="222" HEIGHT="209" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\includegraphics[width=0.4\hsize]{direction.eps}">|; 

1;

==> gerris_0.6.0.orig.tar.gz: tutorial/images.pl <==
# LaTeX2HTML 2002-2-1 (1.70)
# Associate images original text with physical files.


$key = q/delta;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="$ \delta$">|; 

$key = q/displaystyle{|nablatimes{{bf{v}|Deltaxovermax|{{bf{v}|};MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="82" HEIGHT="54" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="$\displaystyle {\vert\nabla\times{\bf v}\vert\Delta x\over\max\vert{\bf v}\vert}$">|; 

$key = q/includegraphics[angle=90,width=0.6hsize]{refined1_cells.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="333" HEIGHT="279" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="\includegraphics[angle=90,width=0.6\hsize]{refined1_cells.eps}">|; 

$key = q/displaystylepi;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="29" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="$\displaystyle \pi$">|; 

$key = q/{figure}center{htmlimage{scale=2.0,external,thumbnail=1}includegraphics[width=hsize]{gfsview.eps}center{{{{figure};FSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<A NAME="figure369"
 HREF="img6.png"><IMG
 WIDTH="368" HEIGHT="328"
 SRC="|."$dir".q|Timg6.png"
 ALT="\begin{figure}\begin{center}
\includegraphics[width=\hsize]{gfsview.eps}
\end{center}
\end{figure}"></A>|; 

$key = q/includegraphics[width=0.3hsize]{half-cylinder.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="167" HEIGHT="167" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="\includegraphics[width=0.3\hsize]{half-cylinder.eps}">|; 

$key = q/displaystyledelta;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$\displaystyle \delta$">|; 

$key = q/includegraphics[angle=90,width=0.8hsize]{boundaries.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="444" HEIGHT="113" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="\includegraphics[angle=90,width=0.8\hsize]{boundaries.eps}">|; 

$key = q/Delta;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="17" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="$ \Delta$">|; 

$key = q/{figure}center{htmlimage{scale=2.0,external,thumbnail=1}includegraphics[width=hsize]{dxscreen.eps}center{{{{figure};FSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<A NAME="figure424"
 HREF="img8.png"><IMG
 WIDTH="368" HEIGHT="328"
 SRC="|."$dir".q|Timg8.png"
 ALT="\begin{figure}\begin{center}
\includegraphics[width=\hsize]{dxscreen.eps}
\end{center}
\end{figure}"></A>|; 

$key = q/includegraphics[angle=90,width=0.6hsize]{refined1.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="333" HEIGHT="279" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="\includegraphics[angle=90,width=0.6\hsize]{refined1.eps}">|; 

$key = q/includegraphics[angle=90,width=0.6hsize]{gfs2oogl.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="332" HEIGHT="284" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="\includegraphics[angle=90,width=0.6\hsize]{gfs2oogl.eps}">|; 

$key = q/includegraphics[angle=90,width=0.8hsize]{refined2.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="444" HEIGHT="113" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="\includegraphics[angle=90,width=0.8\hsize]{refined2.eps}">|; 

$key = q/rightarrow;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$ \rightarrow$">|; 

$key = q/bf{v;MSF=1.6;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="13" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="$ \bf v$">|; 

$key = q/includegraphics[width=0.4hsize]{vorticity.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="222" HEIGHT="222" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="\includegraphics[width=0.4\hsize]{vorticity.eps}">|; 

$key = q/includegraphics[width=0.4hsize]{direction.eps};AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="223" HEIGHT="210" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\includegraphics[width=0.4\hsize]{direction.eps}">|; 

1;
